==> SQL-Statement-Functions-Date-0.01.tar.gz: SQL-Statement-Functions-Date-0.01/lib/SQL/Statement/Function/ByName/DAY.pm <==
package SQL::Statement::Function::ByName::DAY;

our $DATE = '2015-05-09'; # DATE
our $VERSION = '0.01'; # VERSION

use 5.010001;
use strict;
use warnings;

use SQL::Statement::Function::ByName::DAYOFMONTH;

sub DAY {
    goto &SQL::Statement::Function::ByName::DAYOFMONTH::DAYOFMONTH;
}

1;
# ABSTRACT: DAY() SQL function

__END__

=pod

=encoding UTF-8

=head1 NAME

SQL::Statement::Function::ByName::DAY - DAY() SQL function

=head1 VERSION

This document describes version 0.01 of SQL::Statement::Function::ByName::DAY (from Perl distribution SQL-Statement-Functions-Date), released on 2015-05-09.

=head1 DESCRIPTION

Implements DAY() SQL function. It is synonym for DAYOFMONTH().

=for Pod::Coverage .+

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/SQL-Statement-Functions-Date>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-SQL-Statement-Functions-Date>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=SQL-Statement-Functions-Date>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> SQL-Statement-Functions-Date-0.02.tar.gz: SQL-Statement-Functions-Date-0.02/lib/SQL/Statement/Function/ByName/DAY.pm <==
package SQL::Statement::Function::ByName::DAY;

our $DATE = '2015-05-13'; # DATE
our $VERSION = '0.02'; # VERSION

use 5.010001;
use strict;
use warnings;

use SQL::Statement::Function::ByName::DAYOFMONTH;

*SQL_FUNCTION_DAY = \&SQL::Statement::Function::ByName::DAYOFMONTH::SQL_FUNCTION_DAYOFMONTH;

1;
# ABSTRACT: DAY() SQL function

__END__

=pod

=encoding UTF-8

=head1 NAME

SQL::Statement::Function::ByName::DAY - DAY() SQL function

=head1 VERSION

This document describes version 0.02 of SQL::Statement::Function::ByName::DAY (from Perl distribution SQL-Statement-Functions-Date), released on 2015-05-13.

=head1 DESCRIPTION

Implements DAY() SQL function. It is synonym for DAYOFMONTH().

=for Pod::Coverage .+

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/SQL-Statement-Functions-Date>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-SQL-Statement-Functions-Date>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=SQL-Statement-Functions-Date>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
